import { Direction, HealthcareAmounts, Merchant, Relationship, Tags, UnimplementedFields, UnimplementedRelationships } from "./common";
import { ReceivedPaymentStatus } from "./payments";
export declare type UnitEvent = AccountEvents | ApplicationEvents | AuthorizationEvents | CardEvents | CustomerEvents | DocumentApproved | CheckDepositEvents | DocumentRejected | PaymentEvents | StatementsCreated | TransactionEvents | ChargeBackCreated | RewardEvents | DisputeEvents;
export interface BaseEvent {
    id: string;
    type: string;
    attributes: BaseEventAttributes;
    relationships?: UnimplementedRelationships;
}
export interface BaseEventAttributes extends UnimplementedFields {
    createdAt: string;
    tags?: Tags;
}
export interface BaseEventRelationships {
    account: Relationship;
    customer: Relationship;
}
declare type AccountEvents = AccountClosed | AccountFrozen | AccountReopened | AccountUnfrozen;
export declare type AccountClosed = BaseEvent & {
    type: "account.closed";
    attributes: {
        closeReason: string;
    };
    relationships: BaseEventRelationships;
};
export declare type AccountFrozen = BaseEvent & {
    type: "account.frozen";
    attributes: {
        freezeReason: string;
    };
    relationships: BaseEventRelationships;
};
export declare type AccountReopened = BaseEvent & {
    type: "account.reopened";
    relationships: BaseEventRelationships;
};
export declare type AccountUnfrozen = BaseEvent & {
    type: "account.unfrozen";
    relationships: BaseEventRelationships;
};
declare type ApplicationEvents = ApplicationDenied | ApplicationAwaitingDocuments | ApplicationPendingReview;
export declare type ApplicationDenied = BaseEvent & {
    type: "application.denied";
    relationships: {
        application: Relationship;
    };
};
export declare type ApplicationAwaitingDocuments = BaseEvent & {
    type: "application.awaitingDocuments";
    relationships: {
        application: Relationship;
    };
};
export declare type ApplicationPendingReview = BaseEvent & {
    type: "application.pendingReview";
    relationships: {
        application: Relationship;
    };
};
declare type AuthorizationRelationships = BaseEventRelationships & {
    authorization: Relationship;
    card: Relationship;
};
declare type AuthorizationAttributes = BaseEventAttributes & {
    amount: number;
    cardLast4Digits: string;
    recurring: boolean;
};
declare type AuthorizationEvents = AuthorizationCreated | AuthorizationCanceled | AuthorizationDeclined | AuthorizationAmountChanged | AuthorizationRequestApproved | AuthorizationRequestPending | AuthorizationRequestDeclined;
export declare type AuthorizationCreated = BaseEvent & {
    type: "authorization.created";
    attributes: {
        merchant: Merchant;
    } & AuthorizationAttributes;
    relationships: AuthorizationRelationships;
};
export declare type AuthorizationCanceled = BaseEvent & {
    type: "authorization.canceled";
    attributes: AuthorizationAttributes;
    relationships: AuthorizationRelationships;
};
export declare type AuthorizationDeclined = BaseEvent & {
    type: "authorization.declined";
    attributes: {
        reason: string;
    } & AuthorizationAttributes;
    relationships: AuthorizationRelationships;
};
export declare type AuthorizationAmountChanged = BaseEvent & {
    type: "authorization.amountChanged";
    attributes: {
        oldAmount: number;
        newAmount: number;
    };
    relationships: AuthorizationRelationships;
};
declare type AuthorizationRequestRelationships = BaseEventRelationships & {
    authorizationRequest: Relationship;
    card: Relationship;
};
declare type AuthorizationRequestAttributes = BaseEventAttributes & {
    amount: number;
    status: string;
    partialApprovalAllowed: number;
    merchant: Merchant;
    recurring: boolean;
};
export declare type AuthorizationRequestApproved = BaseEvent & {
    type: "authorizationRequest.approved";
    attributes: AuthorizationRequestAttributes & {
        approvedAmount: number;
    };
    relationships: AuthorizationRequestRelationships;
};
export declare type AuthorizationRequestPending = BaseEvent & {
    type: "authorizationRequest.pending";
    attributes: AuthorizationRequestAttributes & {
        available: number;
        ecommerce?: boolean;
        cardPresent?: boolean;
        healthcareAmounts?: HealthcareAmounts;
    };
    relationships: AuthorizationRequestRelationships;
};
export declare type AuthorizationRequestDeclined = BaseEvent & {
    type: "authorizationRequest.declined";
    attributes: AuthorizationRequestAttributes & {
        declineReason: string;
    };
    relationships: AuthorizationRequestRelationships;
};
export declare type BulkPaymentsFailed = BaseEvent & {
    type: "bulkPayments.failed";
    attributes: {
        index: string;
        error: string;
        idempotencyKey?: string;
    };
    relationships: {
        bulkPayments: Relationship;
    };
};
export declare type BulkPaymentsFinished = BaseEvent & {
    type: "bulkPayments.finished";
    relationships: {
        bulkPayments: Relationship;
    };
};
declare type CardEvents = CardActivated | CardStatusChanged;
export declare type CardActivated = BaseEvent & {
    type: "card.activated";
    relationships: {
        card: Relationship;
    } & BaseEventRelationships;
};
export declare type CardStatusChanged = BaseEvent & {
    type: "card.statusChanged";
    attributes: {
        newStatus: string;
        previousStatus: string;
    };
    relationships: {
        card: Relationship;
    } & BaseEventRelationships;
};
declare type CustomerEvents = CustomerCreated | CustomerUpdated | CustomerArchived;
export declare type CustomerCreated = BaseEvent & {
    type: "customer.created";
    relationships: {
        customer: Relationship;
        application: Relationship;
    };
};
export declare type CustomerUpdated = BaseEvent & {
    type: "customer.updated";
    relationships: {
        customer: Relationship;
    };
};
export declare type CustomerArchived = BaseEvent & {
    type: "customer.archived";
    relationships: {
        customer: Relationship;
    };
};
export declare type DocumentApproved = BaseEvent & {
    type: "document.approved";
    relationships: {
        document: Relationship;
        application: Relationship;
    };
};
export declare type DocumentRejected = BaseEvent & {
    type: "document.rejected";
    attributes: {
        reason: string;
        reasonCode: string;
    };
    relationships: {
        document: Relationship;
        application: Relationship;
    };
};
declare type PaymentRelationships = BaseEventRelationships & {
    payment: Relationship;
};
declare type PaymentAttributes = BaseEventAttributes & {
    direction: Direction;
    amount: number;
};
declare type PaymentEvents = PaymentCreated | PaymentClearing | PaymentCanceled | PaymentRejected | PaymentReturned | PaymentSent | PaymentPendingReview | ReceivedPaymentCreated | ReceivedPaymentAdvanced | ReceivedPaymentReturned | ReceivedPaymentCompleted | BulkPaymentsFailed | BulkPaymentsFinished | DeclinedIncomingPayment;
export declare type PaymentCreated = BaseEvent & {
    type: "payment.created";
    attributes: {
        status: string;
    };
    relationships: PaymentRelationships;
};
export declare type PaymentClearing = BaseEvent & {
    type: "payment.clearing";
    attributes: PaymentAttributes & {
        previousStatus: string;
    };
    relationships: PaymentRelationships;
};
export declare type PaymentSent = BaseEvent & {
    type: "payment.sent";
    attributes: PaymentAttributes & {
        previousStatus: string;
    };
    relationships: PaymentRelationships;
};
export declare type PaymentReturned = BaseEvent & {
    type: "payment.returned";
    attributes: PaymentAttributes & {
        previousStatus: string;
    };
    relationships: PaymentRelationships;
};
export declare type PaymentRejected = BaseEvent & {
    type: "payment.rejected";
    attributes: PaymentAttributes & {
        reason: string;
    };
    relationships: PaymentRelationships;
};
export declare type PaymentCanceled = BaseEvent & {
    type: "payment.canceled";
    attributes: PaymentAttributes;
    relationships: PaymentRelationships;
};
export declare type PaymentPendingReview = BaseEvent & {
    type: "payment.pendingReview";
    attributes: PaymentAttributes;
    relationships: PaymentRelationships;
};
export declare type StatementsCreated = BaseEvent & {
    type: "statements.created";
    attributes: {
        period: string;
    };
};
declare type TransactionEvents = TransactionCreated | TransactionUpdated;
export declare type TransactionCreated = BaseEvent & {
    type: "transaction.created";
    attributes: {
        summary: string;
        direction: Direction;
        amount: number;
    };
    relationships: {
        transaction: Relationship;
        payment: Relationship;
    } & BaseEventRelationships;
};
export declare type TransactionUpdated = BaseEvent & {
    type: "transaction.updated";
    attributes: {
        interchange: number;
    };
    relationships: {
        transaction: Relationship;
    };
};
export declare type ReceivedPaymentCreated = BaseEvent & {
    type: "receivedPayment.created";
    attributes: {
        status: ReceivedPaymentStatus;
        type: string;
        amount: number;
        completionDate: string;
        companyName: string;
        counterpartyRoutingNumber: string;
        description: string;
        traceNumber: string;
        secCode: string;
        addenda: string;
    };
    relationships: {
        receivedPayment: Relationship;
    } & BaseEventRelationships;
};
export declare type ReceivedPaymentAdvanced = BaseEvent & {
    type: "receivedPayment.advanced";
    attributes: {
        previousStatus: ReceivedPaymentStatus;
        wasAdvanced: boolean;
    };
    relationships: {
        receivedPayment: Relationship;
    } & BaseEventRelationships;
};
export declare type ReceivedPaymentCompleted = BaseEvent & {
    type: "receivedPayment.completed";
    attributes: {
        previousStatus: ReceivedPaymentStatus;
        wasAdvanced: boolean;
    };
    relationships: {
        receivedPayment: Relationship;
    } & BaseEventRelationships;
};
export declare type ReceivedPaymentReturned = BaseEvent & {
    type: "receivedPayment.returned";
    attributes: {
        previousStatus: ReceivedPaymentStatus;
        wasAdvanced: boolean;
    };
    relationships: {
        receivedPayment: Relationship;
    } & BaseEventRelationships;
};
export declare type ChargeBackCreated = BaseEvent & {
    type: "chargeback.created";
    attributes: {
        amount: number;
        description: string;
    };
    relationships: {
        chargeback: Relationship;
        counterpartyAccount: Relationship;
        transaction: Relationship;
    } & BaseEventRelationships;
};
declare type RewardEvents = RewardSent | RewardRejected;
export declare type RewardSent = BaseEvent & {
    type: "reward.sent";
    relationships: {
        reward: Relationship;
        fundingAccount: Relationship;
        receivingAccount: Relationship;
        customer: Relationship;
    };
};
export declare type RewardRejected = BaseEvent & {
    type: "reward.rejected";
    relationships: {
        reward: Relationship;
        fundingAccount: Relationship;
        receivingAccount: Relationship;
        customer: Relationship;
    };
};
declare type CheckDepositRelationships = {
    checkDeposit: Relationship;
} & BaseEventRelationships;
declare type CheckDepositEvents = CheckDepositCreated | CheckDepositPendingReview | CheckDepositPending | CheckDepositRejected | CheckDepositClearing | CheckDepositSent | CheckDepositReturend;
export declare type CheckDepositCreated = BaseEvent & {
    type: "checkDeposit.created";
    attributes: {
        status: string;
    };
    relationships: CheckDepositRelationships;
};
export declare type CheckDepositPendingReview = BaseEvent & {
    type: "checkDeposit.pendingReview";
    attributes: {
        previousStatus: string;
    };
    relationships: CheckDepositRelationships;
};
export declare type CheckDepositPending = BaseEvent & {
    type: "checkDeposit.pending";
    attributes: {
        previousStatus: string;
    };
    relationships: CheckDepositRelationships;
};
export declare type CheckDepositRejected = BaseEvent & {
    type: "checkDeposit.rejected";
    attributes: {
        previousStatus: string;
        reason: string;
    };
    relationships: CheckDepositRelationships;
};
export declare type CheckDepositClearing = BaseEvent & {
    type: "checkDeposit.clearing";
    attributes: {
        previousStatus: string;
    };
    relationships: CheckDepositRelationships;
};
export declare type CheckDepositSent = BaseEvent & {
    type: "checkDeposit.sent";
    attributes: {
        previousStatus: string;
    };
    relationships: CheckDepositRelationships;
};
export declare type CheckDepositReturend = BaseEvent & {
    type: "checkDeposit.returned";
    attributes: {
        previousStatus: string;
    };
    relationships: CheckDepositRelationships;
};
export declare type DeclinedIncomingPayment = BaseEvent & {
    type: "declinedIncomingPayment.created";
    attributes: {
        amount: number;
        direction: Direction;
        reason: string;
        paymentType: string;
    };
    relationships: BaseEventRelationships;
};
declare type DisputeEvents = DisputeCreated | DisputeStatusChanged;
export declare type DisputeCreated = BaseEvent & {
    type: "dispute.created";
    attributes: {
        amount: number;
        description: string;
        source: string;
        status: string;
    };
    relationships: BaseEventRelationships & {
        dispute: Relationship;
        transaction: Relationship;
    };
};
export declare type DisputeStatusChanged = BaseEvent & {
    type: "dispute.statusChanged";
    attributes: {
        amount: number;
        previousStatus: string;
        newStatus: string;
    };
    relationships: BaseEventRelationships & {
        dispute: Relationship;
        transaction: Relationship;
    };
};
export {};
